ensure_log_error

Function ensure_log_error 

pub fn ensure_log_error(error: &Error)
Logs error via the tracing subscriber if one is configured, or prints to stderr otherwise.

Use this in binary entry points where the subscriber may or may not have been initialized yet, such as in main when a fatal error occurs before or during initialization.